It shouldn't add much overhead and we should make sure that critical
VRAM content is always restored.

Signed-off-by: Christian König <christian.koe...@amd.com>
Acked-by: Junwei Zhang <jerry.zh...@amd.com>
---
 drivers/gpu/drm/amd/amdgpu/amdgpu_device.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_device.c 
b/drivers/gpu/drm/amd/amdgpu/amdgpu_device.c
index 762dc5f886cd..899342c6dfad 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_device.c
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_device.c
@@ -3003,7 +3003,7 @@ static int amdgpu_device_recover_vram_from_shadow(struct 
amdgpu_device *adev,
 }
 
 /**
  * amdgpu_device_handle_vram_lost - Handle the loss of VRAM contents
  *
  * @adev: amdgpu_device pointer
  *
@@ -3012,7 +3012,7 @@ static int amdgpu_device_recover_vram_from_shadow(struct 
amdgpu_device *adev,
  * the contents of VRAM might be lost.
  * Returns 0 on success, 1 on failure.
  */
-static int amdgpu_device_handle_vram_lost(struct amdgpu_device *adev)
+static int amdgpu_device_recover_vram(struct amdgpu_device *adev)
 {
        struct amdgpu_ring *ring = adev->mman.buffer_funcs_ring;
        struct amdgpu_bo *bo, *tmp;
@@ -3139,8 +3139,8 @@ static int amdgpu_device_reset(struct amdgpu_device *adev)
                }
        }
 
-       if (!r && ((need_full_reset && !(adev->flags & AMD_IS_APU)) || 
vram_lost))
-               r = amdgpu_device_handle_vram_lost(adev);
+       if (!r)
+               r = amdgpu_device_recover_vram(adev);
 
        return r;
 }
@@ -3186,7 +3186,7 @@ static int amdgpu_device_reset_sriov(struct amdgpu_device 
*adev,
        amdgpu_virt_release_full_gpu(adev, true);
        if (!r && adev->virt.gim_feature & AMDGIM_FEATURE_GIM_FLR_VRAMLOST) {
                atomic_inc(&adev->vram_lost_counter);
-               r = amdgpu_device_handle_vram_lost(adev);
+               r = amdgpu_device_recover_vram(adev);
        }
 
        return r;
@@ -3003,7 +3003,7 @@ static int amdgpu_device_recover_vram_from_shadow(struct 
 
 /**
- * amdgpu_device_handle_vram_lost - Handle the loss of VRAM contents
+ * amdgpu_device_recover_vram - Recover some VRAM contents
  *
  * @adev: amdgpu_device pointer
-- 
2.14.1

_______________________________________________
amd-gfx mailing list
amd-gfx@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/amd-gfx

Reply via email to